==> vue-router-query-1.1.6.tgz: package/src/history/query.js <==
/* @flow */

import type Router from '../index'
import { History } from './base'
import { cleanPath } from '../util/path'
import { getLocation } from './html5'
import { setupScroll, handleScroll } from '../util/scroll'
import { pushState, replaceState, supportsPushState } from '../util/push-state'

export class QueryHistory extends History {
  constructor(router: Router, base: ?string, fallback: boolean) {
    super(router, base)
    // check history fallback deeplinking
    if (fallback && checkFallback(this.base)) {
      return
    }
    ensureSlash()
  }

  // this is delayed until the app mounts
  // to avoid the hashchange listener being fired too early
  setupListeners() {
    if (this.listeners.length > 0) {
      return
    }

    const router = this.router
    const expectScroll = router.options.scrollBehavior
    const supportsScroll = supportsPushState && expectScroll

    if (supportsScroll) {
      this.listeners.push(setupScroll())
    }

    const handleRoutingEvent = () => {
      const current = this.current
      if (!ensureSlash()) {
        return
      }
      this.transitionTo(getHash(), route => {
        if (supportsScroll) {
          handleScroll(this.router, route, current, true)
        }
        if (!supportsPushState) {
          replaceHash(route.fullPath)
        }
      })
    }
    const eventType = supportsPushState ? 'popstate' : 'hashchange'
    window.addEventListener(
      eventType,
      handleRoutingEvent
    )
    this.listeners.push(() => {
      window.removeEventListener(eventType, handleRoutingEvent)
    })
  }

  push(location: RawLocation, onComplete?: Function, onAbort?: Function) {
    const { current: fromRoute } = this
    this.transitionTo(
      location,
      route => {
        pushHash('r=' + ('' + route.fullPath).replace(/\?/g, '&'))
        handleScroll(this.router, route, fromRoute, false)
        onComplete && onComplete(route)
      },
      onAbort
    )
  }

  replace(location: RawLocation, onComplete?: Function, onAbort?: Function) {
    const { current: fromRoute } = this
    this.transitionTo(
      location,
      route => {
        replaceHash('r=' + route.fullPath.replace(/\?/g, '&'))
        handleScroll(this.router, route, fromRoute, false)
        onComplete && onComplete(route)
      },
      onAbort
    )
  }

  go(n: number) {
    window.history.go(n)
  }

  ensureURL(push?: boolean) {
    const current = this.current.fullPath[0] != '/' ? '/' + this.current.fullPath : this.current.fullPath
    if (getHash() !== current) {
      push ? pushHash(current) : replaceHash(current)
    }
  }

  getCurrentLocation() {
    return getHash();
  }
}

function checkFallback(base) {
  const location = getLocation(base)
  
  if (!/^\#/.test(location)) {
    debugger
    window.location.replace(cleanPath(base + '?r=' + location))
    return true
  }

}

function ensureSlash(): boolean {
  const path = getHash()
  if (path.charAt(0) === '/') {
    return true
  }

  replaceHash(path)
  return false
}

export function getHash(): string {
  // We can't use window.location.hash here because it's not
  // consistent across browsers - Firefox will pre-decode it!
  let href = window.location.href
  const index = href.indexOf('?r=')
  // empty path
  if (index < 0) return ''

  href = href.slice(index + 3)
  href = href.replace('&', '?');
  return href[0] != '/' ? '/' + href : href;
}

const parse = function searchObj(search) {
  try {
    return JSON.parse("{\"".concat(decodeURIComponent(search.substring(1)).replace(/"/g, '\\"').replace(/&/g, '","').replace(/=/g, '":"'), "\"}"));
  } catch (error) {
    return {r:''};
  }
  
};

function getUrl(path) {
  const href = window.location.href
  const i = href.indexOf('?')
  const base = i >= 0 ? href.slice(0, i) : href
  const query = path ? parse('?' + path) : { r: '/' }
  const search = Object.keys(query).map(function (key) {
    return key !== 'r' && key !== '/r' ? key + "=" + encodeURIComponent(query[key]) : ''
  }).join("&");

  return `${base}?r=${query.r || query['/r']}${search ? `${search}` : ''} `
}

function pushHash(path) {
  if (supportsPushState) {
    pushState(getUrl(path))
  } else {
    window.location.hash = path
  }
}

function replaceHash(path) {
  if(!path||path == '/') return false;
  if (supportsPushState) {
    replaceState(getUrl(path))
  } else {
     
    window.location.replace(getUrl(path))
  }
}

==> vue-router-query-1.1.7.tgz: package/src/history/query.js <==
/* @flow */

import type Router from '../index'
import { History } from './base'
import { cleanPath } from '../util/path'
import { getLocation } from './html5'
import { setupScroll, handleScroll } from '../util/scroll'
import { pushState, replaceState, supportsPushState } from '../util/push-state'

export class QueryHistory extends History {
  constructor(router: Router, base: ?string, fallback: boolean) {
    super(router, base)
    // check history fallback deeplinking
    if (fallback && checkFallback(this.base)) {
      return
    }
    ensureSlash()
  }

  // this is delayed until the app mounts
  // to avoid the hashchange listener being fired too early
  setupListeners() {
    if (this.listeners.length > 0) {
      return
    }

    const router = this.router
    const expectScroll = router.options.scrollBehavior
    const supportsScroll = supportsPushState && expectScroll

    if (supportsScroll) {
      this.listeners.push(setupScroll())
    }

    const handleRoutingEvent = () => {
      const current = this.current
      if (!ensureSlash()) {
        return
      }
      this.transitionTo(getHash(), route => {
        if (supportsScroll) {
          handleScroll(this.router, route, current, true)
        }
        if (!supportsPushState) {
          replaceHash(route.fullPath)
        }
      })
    }
    const eventType = supportsPushState ? 'popstate' : 'hashchange'
    window.addEventListener(
      eventType,
      handleRoutingEvent
    )
    this.listeners.push(() => {
      window.removeEventListener(eventType, handleRoutingEvent)
    })
  }

  push(location: RawLocation, onComplete?: Function, onAbort?: Function) {
    const { current: fromRoute } = this
    this.transitionTo(
      location,
      route => {
        pushHash('r=' + ('' + route.fullPath).replace(/\?/g, '&'))
        handleScroll(this.router, route, fromRoute, false)
        onComplete && onComplete(route)
      },
      onAbort
    )
  }

  replace(location: RawLocation, onComplete?: Function, onAbort?: Function) {
    const { current: fromRoute } = this
    this.transitionTo(
      location,
      route => {
        replaceHash('r=' + route.fullPath.replace(/\?/g, '&'))
        handleScroll(this.router, route, fromRoute, false)
        onComplete && onComplete(route)
      },
      onAbort
    )
  }

  go(n: number) {
    window.history.go(n)
  }

  ensureURL(push?: boolean) {
    const current = this.current.fullPath[0] != '/' ? '/' + this.current.fullPath : this.current.fullPath
    if (getHash() !== current) {
      push ? pushHash(current) : replaceHash(current,true)
    }
  }

  getCurrentLocation() {
    return getHash();
  }
}

function checkFallback(base) {
  const location = getLocation(base)
  
  if (!/^\#/.test(location)) {
    window.location.replace(cleanPath(base + '?r=' + location))
    return true
  }

}

function ensureSlash(): boolean {
  const path = getHash()
  if (path.charAt(0) === '/') {
    return true
  }

  replaceHash(path)
  return false
}

export function getHash(): string {
  // We can't use window.location.hash here because it's not
  // consistent across browsers - Firefox will pre-decode it!
  let href = window.location.href
  const index = href.indexOf('?r=')
  // empty path
  if (index < 0) return ''

  href = href.slice(index + 3)
  href = href.replace('&', '?');
  return href[0] != '/' ? '/' + href : href;
}

const parse = function searchObj(search) {
  try {
    return JSON.parse("{\"".concat(decodeURIComponent(search.substring(1)).replace(/"/g, '\\"').replace(/&/g, '","').replace(/=/g, '":"'), "\"}"));
  } catch (error) {
    return {r:''};
  }
  
};

function getUrl(path) {
  const href = window.location.href
  const i = href.indexOf('?')
  const base = i >= 0 ? href.slice(0, i) : href
  const query = path && path != '/' ? parse((path.indexOf('?')>-1 ? '' : '?') + path) : { r: '/' }
  const search = Object.keys(query).map(function (key) {
    return key !== 'r' && key !== '/r' ? key + "=" + encodeURIComponent(query[key]) : ''
  }).join("&");

  return `${base}?r=${query.r || query['/r']}${search ? `${search}` : ''} `
}

function pushHash(path) {
  if (supportsPushState) {
    pushState(getUrl(path))
  } else {
    window.location.hash = path
  }
}
let isRouterReLoading = true;
function replaceHash(path,isLoading) {
  if (supportsPushState) {
    if(((!path||path == '/') && isRouterReLoading)||isLoading){
      isRouterReLoading =false;
      // 首次进入网站 进入二级页面返回时候强制刷新app解决路由不刷新问题当前未排查到逻辑暂时这样处理
    }else if((!path||path == '/')){
      window.location.replace(getUrl(path))
    }else{
      replaceState(getUrl(path))
    }
    
  } else {
     
    window.location.replace(getUrl(path))
  }
}
